from .return_class import AbstractApiClass


class FileConnector(AbstractApiClass):
    """
        Verification result for an external storage service

        Args:
            client (ApiClient): An authenticated API Client instance
            bucket (str): The address of the bucket. eg., `s3://your-bucket`
            verified (bool): `true` if the bucket has passed verification
            writePermission (bool): `true` if Abacus.AI has permission to write to this bucket
            authExpiresAt (str): The time when the file connector's auth expires, if applicable
            createdAt (str): The timestamp at which the file connector was created
    """

    def __init__(self, client, bucket=None, verified=None, writePermission=None, authExpiresAt=None, createdAt=None):
        super().__init__(client, None)
        self.bucket = bucket
        self.verified = verified
        self.write_permission = writePermission
        self.auth_expires_at = authExpiresAt
        self.created_at = createdAt
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'bucket': repr(self.bucket), f'verified': repr(self.verified), f'write_permission': repr(
            self.write_permission), f'auth_expires_at': repr(self.auth_expires_at), f'created_at': repr(self.created_at)}
        class_name = "FileConnector"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'bucket': self.bucket, 'verified': self.verified, 'write_permission': self.write_permission,
                'auth_expires_at': self.auth_expires_at, 'created_at': self.created_at}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class Vertical(AbstractApiClass):
    """
        A ChatLLM Vertical (e.g., Health).

        Args:
            client (ApiClient): An authenticated API Client instance
            externalApplicationId (str): The ID of the vertical's external application.
            deploymentId (str): The ID of the vertical's deployment.
            name (str): The name of the vertical.
            description (str): The description of the vertical.
            verticalType (str): The type of vertical (e.g., HEALTH).
    """

    def __init__(self, client, externalApplicationId=None, deploymentId=None, name=None, description=None, verticalType=None):
        super().__init__(client, None)
        self.external_application_id = externalApplicationId
        self.deployment_id = deploymentId
        self.name = name
        self.description = description
        self.vertical_type = verticalType
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'external_application_id': repr(self.external_application_id), f'deployment_id': repr(
            self.deployment_id), f'name': repr(self.name), f'description': repr(self.description), f'vertical_type': repr(self.vertical_type)}
        class_name = "Vertical"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'external_application_id': self.external_application_id, 'deployment_id': self.deployment_id,
                'name': self.name, 'description': self.description, 'vertical_type': self.vertical_type}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class NestedFeature(AbstractApiClass):
    """
        A nested feature in a feature group

        Args:
            client (ApiClient): An authenticated API Client instance
            name (str): The unique name of the column
            selectClause (str): The sql logic for creating this feature's data
            featureType (str): Feature Type of the Feature
            featureMapping (str): The Feature Mapping of the feature
            dataType (str): Data Type of the Feature
            sourceTable (str): The source table of the column
            originalName (str): The original name of the column
    """

    def __init__(self, client, name=None, selectClause=None, featureType=None, featureMapping=None, dataType=None, sourceTable=None, originalName=None):
        super().__init__(client, None)
        self.name = name
        self.select_clause = selectClause
        self.feature_type = featureType
        self.feature_mapping = featureMapping
        self.data_type = dataType
        self.source_table = sourceTable
        self.original_name = originalName
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'name': repr(self.name), f'select_clause': repr(self.select_clause), f'feature_type': repr(self.feature_type), f'feature_mapping': repr(
            self.feature_mapping), f'data_type': repr(self.data_type), f'source_table': repr(self.source_table), f'original_name': repr(self.original_name)}
        class_name = "NestedFeature"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'name': self.name, 'select_clause': self.select_clause, 'feature_type': self.feature_type, 'feature_mapping': self.feature_mapping,
                'data_type': self.data_type, 'source_table': self.source_table, 'original_name': self.original_name}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class PageData(AbstractApiClass):
    """
        Data extracted from a docstore page.

        Args:
            client (ApiClient): An authenticated API Client instance
            docId (str): Unique Docstore string identifier for the document.
            page (int): The page number. Starts from 0.
            height (int): The height of the page in pixels.
            width (int): The width of the page in pixels.
            pageCount (int): The total number of pages in document.
            pageText (str): The text extracted from the page.
            pageTokenStartOffset (int): The offset of the first token in the page.
            tokenCount (int): The number of tokens in the page.
            tokens (list): The tokens in the page.
            extractedText (str): The extracted text in the page obtained from OCR.
            rotationAngle (float): The detected rotation angle of the page in degrees. Positive values indicate clockwise and negative values indicate anti-clockwise rotation from the original orientation.
            pageMarkdown (str): The markdown text for the page.
            embeddedText (str): The embedded text in the page. Only available for digital documents.
    """

    def __init__(self, client, docId=None, page=None, height=None, width=None, pageCount=None, pageText=None, pageTokenStartOffset=None, tokenCount=None, tokens=None, extractedText=None, rotationAngle=None, pageMarkdown=None, embeddedText=None):
        super().__init__(client, None)
        self.doc_id = docId
        self.page = page
        self.height = height
        self.width = width
        self.page_count = pageCount
        self.page_text = pageText
        self.page_token_start_offset = pageTokenStartOffset
        self.token_count = tokenCount
        self.tokens = tokens
        self.extracted_text = extractedText
        self.rotation_angle = rotationAngle
        self.page_markdown = pageMarkdown
        self.embedded_text = embeddedText
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'doc_id': repr(self.doc_id), f'page': repr(self.page), f'height': repr(self.height), f'width': repr(self.width), f'page_count': repr(self.page_count), f'page_text': repr(self.page_text), f'page_token_start_offset': repr(
            self.page_token_start_offset), f'token_count': repr(self.token_count), f'tokens': repr(self.tokens), f'extracted_text': repr(self.extracted_text), f'rotation_angle': repr(self.rotation_angle), f'page_markdown': repr(self.page_markdown), f'embedded_text': repr(self.embedded_text)}
        class_name = "PageData"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'doc_id': self.doc_id, 'page': self.page, 'height': self.height, 'width': self.width, 'page_count': self.page_count, 'page_text': self.page_text, 'page_token_start_offset': self.page_token_start_offset,
                'token_count': self.token_count, 'tokens': self.tokens, 'extracted_text': self.extracted_text, 'rotation_angle': self.rotation_angle, 'page_markdown': self.page_markdown, 'embedded_text': self.embedded_text}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass
from .user import User


class AppUserGroup(AbstractApiClass):
    """
        An app user group. This is used to determine which users have permissions for external chatbots.

        Args:
            client (ApiClient): An authenticated API Client instance
            name (str): The name of the user group.
            userGroupId (str): The unique identifier of the user group.
            externalApplicationIds (list[str]): The ids of the external applications the group has access to.
            invitedUserEmails (list[str]): The emails of the users invited to the user group who have not yet accepted the invite.
            publicUserGroup (bool): Boolean flag whether the app user group is the public user group of the org or not.
            hasExternalApplicationReporting (bool): Whether users in the App User Group have permission to view all reports in their organization.
            isExternalServiceGroup (bool): Whether the App User Group corresponds to a user group that's defined in an external service (i.e Microsft Active Directory or Okta) or not
            externalServiceGroupId (str): The identifier that corresponds to the app user group's external service group representation
            creationSource (str): The source of the app user group
            users (User): The users in the user group.
    """

    def __init__(self, client, name=None, userGroupId=None, externalApplicationIds=None, invitedUserEmails=None, publicUserGroup=None, hasExternalApplicationReporting=None, isExternalServiceGroup=None, externalServiceGroupId=None, creationSource=None, users={}):
        super().__init__(client, None)
        self.name = name
        self.user_group_id = userGroupId
        self.external_application_ids = externalApplicationIds
        self.invited_user_emails = invitedUserEmails
        self.public_user_group = publicUserGroup
        self.has_external_application_reporting = hasExternalApplicationReporting
        self.is_external_service_group = isExternalServiceGroup
        self.external_service_group_id = externalServiceGroupId
        self.creation_source = creationSource
        self.users = client._build_class(User, users)
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'name': repr(self.name), f'user_group_id': repr(self.user_group_id), f'external_application_ids': repr(self.external_application_ids), f'invited_user_emails': repr(self.invited_user_emails), f'public_user_group': repr(self.public_user_group), f'has_external_application_reporting': repr(
            self.has_external_application_reporting), f'is_external_service_group': repr(self.is_external_service_group), f'external_service_group_id': repr(self.external_service_group_id), f'creation_source': repr(self.creation_source), f'users': repr(self.users)}
        class_name = "AppUserGroup"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'name': self.name, 'user_group_id': self.user_group_id, 'external_application_ids': self.external_application_ids, 'invited_user_emails': self.invited_user_emails, 'public_user_group': self.public_user_group, 'has_external_application_reporting':
                self.has_external_application_reporting, 'is_external_service_group': self.is_external_service_group, 'external_service_group_id': self.external_service_group_id, 'creation_source': self.creation_source, 'users': self._get_attribute_as_dict(self.users)}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from typing import List

from .return_class import AbstractApiClass


class GraphDashboard(AbstractApiClass):
    """
        A Graph Dashboard

        Args:
            client (ApiClient): An authenticated API Client instance
            name (str): The user-friendly name for the graph dashboard.
            graphDashboardId (str): The unique identifier of the graph dashboard.
            createdAt (str): Date and time at which the graph dashboard was created, in ISO-8601 format.
            projectId (str): The unique identifier of the project this graph dashboard belongs to.
            pythonFunctionIds (list[str]): List of Python function IDs included in the dashboard.
            plotReferenceIds (list[str]): List of the graph reference IDs for the plots to the dashboard.
            pythonFunctionNames (list[str]): List of names of each of the plots to the dashboard.
            projectName (str): The name the graph dashboard belongs to.
            description (str): The description of the graph dashboard.
    """

    def __init__(self, client, name=None, graphDashboardId=None, createdAt=None, projectId=None, pythonFunctionIds=None, plotReferenceIds=None, pythonFunctionNames=None, projectName=None, description=None):
        super().__init__(client, graphDashboardId)
        self.name = name
        self.graph_dashboard_id = graphDashboardId
        self.created_at = createdAt
        self.project_id = projectId
        self.python_function_ids = pythonFunctionIds
        self.plot_reference_ids = plotReferenceIds
        self.python_function_names = pythonFunctionNames
        self.project_name = projectName
        self.description = description
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'name': repr(self.name), f'graph_dashboard_id': repr(self.graph_dashboard_id), f'created_at': repr(self.created_at), f'project_id': repr(self.project_id), f'python_function_ids': repr(
            self.python_function_ids), f'plot_reference_ids': repr(self.plot_reference_ids), f'python_function_names': repr(self.python_function_names), f'project_name': repr(self.project_name), f'description': repr(self.description)}
        class_name = "GraphDashboard"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'name': self.name, 'graph_dashboard_id': self.graph_dashboard_id, 'created_at': self.created_at, 'project_id': self.project_id, 'python_function_ids': self.python_function_ids,
                'plot_reference_ids': self.plot_reference_ids, 'python_function_names': self.python_function_names, 'project_name': self.project_name, 'description': self.description}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}

    def refresh(self):
        """
        Calls describe and refreshes the current object's fields

        Returns:
            GraphDashboard: The current object
        """
        self.__dict__.update(self.describe().__dict__)
        return self

    def describe(self):
        """
        Describes a given graph dashboard.

        Args:
            graph_dashboard_id (str): Unique identifier for the graph dashboard.

        Returns:
            GraphDashboard: An object containing information about the graph dashboard.
        """
        return self.client.describe_graph_dashboard(self.graph_dashboard_id)

    def delete(self):
        """
        Deletes a graph dashboard

        Args:
            graph_dashboard_id (str): Unique string identifier for the graph dashboard to be deleted.
        """
        return self.client.delete_graph_dashboard(self.graph_dashboard_id)

    def update(self, name: str = None, python_function_ids: List = None):
        """
        Updates a graph dashboard

        Args:
            name (str): Name of the dashboard.
            python_function_ids (List): List of unique string identifiers for the Python functions to be used in the graph dashboard.

        Returns:
            GraphDashboard: An object describing the graph dashboard.
        """
        return self.client.update_graph_dashboard(self.graph_dashboard_id, name, python_function_ids)



from .return_class import AbstractApiClass


class EdaCollinearity(AbstractApiClass):
    """
        Eda Collinearity of the latest version of the data between all the features.

        Args:
            client (ApiClient): An authenticated API Client instance
            columnNames (list): Name of all the features in the y axis of the collinearity matrix
            collinearityMatrix (dict): A dict describing the collinearity between all the features
            groupFeatureDict (dict): A dict describing the index of the group from collinearity_groups a feature exists in
            collinearityGroups (list): Groups created based on a collinearity threshold of 0.7
            columnNamesX (list): Name of all the features in the x axis of the collinearity matrix
    """

    def __init__(self, client, columnNames=None, collinearityMatrix=None, groupFeatureDict=None, collinearityGroups=None, columnNamesX=None):
        super().__init__(client, None)
        self.column_names = columnNames
        self.collinearity_matrix = collinearityMatrix
        self.group_feature_dict = groupFeatureDict
        self.collinearity_groups = collinearityGroups
        self.column_names_x = columnNamesX
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'column_names': repr(self.column_names), f'collinearity_matrix': repr(self.collinearity_matrix), f'group_feature_dict': repr(
            self.group_feature_dict), f'collinearity_groups': repr(self.collinearity_groups), f'column_names_x': repr(self.column_names_x)}
        class_name = "EdaCollinearity"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'column_names': self.column_names, 'collinearity_matrix': self.collinearity_matrix, 'group_feature_dict':
                self.group_feature_dict, 'collinearity_groups': self.collinearity_groups, 'column_names_x': self.column_names_x}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class AuditLog(AbstractApiClass):
    """
        An audit log entry

        Args:
            client (ApiClient): An authenticated API Client instance
            createdAt (str): The timestamp when the audit log entry was created
            userId (str): The hashed ID of the user who performed the action
            objectId (str): The hashed ID of the object that was affected by the action
            action (str): The action performed (create, modify, start, stop, delete, share, hide, credential_change, login)
            source (str): The source of the action (api, ui, pipeline, cli, system)
            refreshPolicyId (str): The hashed ID of the refresh policy if applicable
            pipelineId (str): The hashed ID of the pipeline if applicable
    """

    def __init__(self, client, createdAt=None, userId=None, objectId=None, action=None, source=None, refreshPolicyId=None, pipelineId=None):
        super().__init__(client, None)
        self.created_at = createdAt
        self.user_id = userId
        self.object_id = objectId
        self.action = action
        self.source = source
        self.refresh_policy_id = refreshPolicyId
        self.pipeline_id = pipelineId
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'created_at': repr(self.created_at), f'user_id': repr(self.user_id), f'object_id': repr(self.object_id), f'action': repr(
            self.action), f'source': repr(self.source), f'refresh_policy_id': repr(self.refresh_policy_id), f'pipeline_id': repr(self.pipeline_id)}
        class_name = "AuditLog"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'created_at': self.created_at, 'user_id': self.user_id, 'object_id': self.object_id, 'action': self.action,
                'source': self.source, 'refresh_policy_id': self.refresh_policy_id, 'pipeline_id': self.pipeline_id}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class RoutingAction(AbstractApiClass):
    """
        Routing action

        Args:
            client (ApiClient): An authenticated API Client instance
            id (str): The id of the routing action.
            title (str): The title of the routing action.
            prompt (str): The prompt of the routing action.
            placeholder (str): The placeholder of the routing action.
            value (str): The value of the routing action.
            displayName (str): The display name of the routing action.
            isLarge (bool): UI placement
            isMedium (bool): UI placement
            additionalInfo (dict): Additional information for the routing action.
    """

    def __init__(self, client, id=None, title=None, prompt=None, placeholder=None, value=None, displayName=None, isLarge=None, isMedium=None, additionalInfo=None):
        super().__init__(client, None)
        self.id = id
        self.title = title
        self.prompt = prompt
        self.placeholder = placeholder
        self.value = value
        self.display_name = displayName
        self.is_large = isLarge
        self.is_medium = isMedium
        self.additional_info = additionalInfo
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'id': repr(self.id), f'title': repr(self.title), f'prompt': repr(self.prompt), f'placeholder': repr(self.placeholder), f'value': repr(
            self.value), f'display_name': repr(self.display_name), f'is_large': repr(self.is_large), f'is_medium': repr(self.is_medium), f'additional_info': repr(self.additional_info)}
        class_name = "RoutingAction"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'id': self.id, 'title': self.title, 'prompt': self.prompt, 'placeholder': self.placeholder, 'value': self.value,
                'display_name': self.display_name, 'is_large': self.is_large, 'is_medium': self.is_medium, 'additional_info': self.additional_info}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class ModelMonitorOrgSummary(AbstractApiClass):
    """
        A summary of an organization's model monitors

        Args:
            client (ApiClient): An authenticated API Client instance
            summary (dict): Count of monitors, count of versions, count of total rows of prediction data, count of failed versions.
            featureDrift (dict): Percentage of monitors with and without KL divergence > 2.
            labelDrift (dict): Histogram of label drift across versions.
            dataIntegrity (dict): Counts of violations.
            performance (dict): Model accuracy information.
            alerts (dict): Count of alerts that are raised.
            monitorData (dict): Information about monitors used in the summary for each time period.
            totalStarredMonitors (int): Total number of starred monitors.
    """

    def __init__(self, client, summary=None, featureDrift=None, labelDrift=None, dataIntegrity=None, performance=None, alerts=None, monitorData=None, totalStarredMonitors=None):
        super().__init__(client, None)
        self.summary = summary
        self.feature_drift = featureDrift
        self.label_drift = labelDrift
        self.data_integrity = dataIntegrity
        self.performance = performance
        self.alerts = alerts
        self.monitor_data = monitorData
        self.total_starred_monitors = totalStarredMonitors
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'summary': repr(self.summary), f'feature_drift': repr(self.feature_drift), f'label_drift': repr(self.label_drift), f'data_integrity': repr(self.data_integrity), f'performance': repr(
            self.performance), f'alerts': repr(self.alerts), f'monitor_data': repr(self.monitor_data), f'total_starred_monitors': repr(self.total_starred_monitors)}
        class_name = "ModelMonitorOrgSummary"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'summary': self.summary, 'feature_drift': self.feature_drift, 'label_drift': self.label_drift, 'data_integrity': self.data_integrity,
                'performance': self.performance, 'alerts': self.alerts, 'monitor_data': self.monitor_data, 'total_starred_monitors': self.total_starred_monitors}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class CodeSource(AbstractApiClass):
    """
        Code source for python-based custom feature groups and models

        Args:
            client (ApiClient): An authenticated API Client instance
            sourceType (str): The type of the source, one of TEXT, PYTHON, FILE_UPLOAD, or APPLICATION_CONNECTOR
            sourceCode (str): If the type of the source is TEXT, the raw text of the function
            applicationConnectorId (str): The Application Connector to fetch the code from
            applicationConnectorInfo (str): Args passed to the application connector to fetch the code
            packageRequirements (list): The pip package dependencies required to run the code
            status (str): The status of the code and validations
            error (str): If the status is failed, an error message describing what went wrong
            publishingMsg (dict): Warnings in the source code
            moduleDependencies (list): The list of internal modules dependencies required to run the code
    """

    def __init__(self, client, sourceType=None, sourceCode=None, applicationConnectorId=None, applicationConnectorInfo=None, packageRequirements=None, status=None, error=None, publishingMsg=None, moduleDependencies=None):
        super().__init__(client, None)
        self.source_type = sourceType
        self.source_code = sourceCode
        self.application_connector_id = applicationConnectorId
        self.application_connector_info = applicationConnectorInfo
        self.package_requirements = packageRequirements
        self.status = status
        self.error = error
        self.publishing_msg = publishingMsg
        self.module_dependencies = moduleDependencies
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'source_type': repr(self.source_type), f'source_code': repr(self.source_code), f'application_connector_id': repr(self.application_connector_id), f'application_connector_info': repr(
            self.application_connector_info), f'package_requirements': repr(self.package_requirements), f'status': repr(self.status), f'error': repr(self.error), f'publishing_msg': repr(self.publishing_msg), f'module_dependencies': repr(self.module_dependencies)}
        class_name = "CodeSource"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'source_type': self.source_type, 'source_code': self.source_code, 'application_connector_id': self.application_connector_id, 'application_connector_info': self.application_connector_info,
                'package_requirements': self.package_requirements, 'status': self.status, 'error': self.error, 'publishing_msg': self.publishing_msg, 'module_dependencies': self.module_dependencies}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}

    def import_as_cell(self):
        """
        Adds the source code as an unexecuted cell in the notebook.
        """
        if not self.source_code:
            print('No source code to import.')
        from IPython.core.getipython import get_ipython
        try:
            shell = get_ipython()
            shell.set_next_input(self.source_code)
        except Exception:
            print('Unable to import source code as cells.')



from .return_class import AbstractApiClass


class HostnameInfo(AbstractApiClass):
    """
        Hostname Info

        Args:
            client (ApiClient): An authenticated API Client instance
            hostname (str): IDN formatted hostname
            isRootDomain (bool): Whether the hostname is a root domain
            hasRootNameserversConfigured (bool): Whether the root domain has Abacus nameservers configured.
    """

    def __init__(self, client, hostname=None, isRootDomain=None, hasRootNameserversConfigured=None):
        super().__init__(client, None)
        self.hostname = hostname
        self.is_root_domain = isRootDomain
        self.has_root_nameservers_configured = hasRootNameserversConfigured
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'hostname': repr(self.hostname), f'is_root_domain': repr(
            self.is_root_domain), f'has_root_nameservers_configured': repr(self.has_root_nameservers_configured)}
        class_name = "HostnameInfo"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'hostname': self.hostname, 'is_root_domain': self.is_root_domain,
                'has_root_nameservers_configured': self.has_root_nameservers_configured}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class DeploymentStatistics(AbstractApiClass):
    """
        A set of statistics for a realtime deployment.

        Args:
            client (ApiClient): An authenticated API Client instance
            requestSeries (list): A list of the number of requests per second.
            latencySeries (list): A list of the latency in milliseconds for each request.
            dateLabels (list): A list of date labels for each point in the series.
            httpStatusSeries (list): A list of the HTTP status codes for each request.
    """

    def __init__(self, client, requestSeries=None, latencySeries=None, dateLabels=None, httpStatusSeries=None):
        super().__init__(client, None)
        self.request_series = requestSeries
        self.latency_series = latencySeries
        self.date_labels = dateLabels
        self.http_status_series = httpStatusSeries
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'request_series': repr(self.request_series), f'latency_series': repr(
            self.latency_series), f'date_labels': repr(self.date_labels), f'http_status_series': repr(self.http_status_series)}
        class_name = "DeploymentStatistics"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'request_series': self.request_series, 'latency_series': self.latency_series,
                'date_labels': self.date_labels, 'http_status_series': self.http_status_series}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class ChatllmComputerStatus(AbstractApiClass):
    """
        ChatLLM Computer Status

        Args:
            client (ApiClient): An authenticated API Client instance
            computerId (str): The ID of the computer, it can be a deployment_conversation_id or a computer_id (TODO: add separate field for deployment_conversation_id)
            vncEndpoint (str): The VNC endpoint of the computer
            computerStarted (bool): Whether the computer has started
            restartRequired (bool): Whether the computer needs to be restarted
    """

    def __init__(self, client, computerId=None, vncEndpoint=None, computerStarted=None, restartRequired=None):
        super().__init__(client, None)
        self.computer_id = computerId
        self.vnc_endpoint = vncEndpoint
        self.computer_started = computerStarted
        self.restart_required = restartRequired
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'computer_id': repr(self.computer_id), f'vnc_endpoint': repr(
            self.vnc_endpoint), f'computer_started': repr(self.computer_started), f'restart_required': repr(self.restart_required)}
        class_name = "ChatllmComputerStatus"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'computer_id': self.computer_id, 'vnc_endpoint': self.vnc_endpoint,
                'computer_started': self.computer_started, 'restart_required': self.restart_required}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class McpServer(AbstractApiClass):
    """
        Model Context Protocol Server

        Args:
            client (ApiClient): An authenticated API Client instance
            name (str): The name of the MCP server.
            description (str): description of what the MCP server does.
            envVars (list): list of api_keys or credentials required by the MCP server.
            config (str): a json string containing the command and arguments for the MCP server.
            envVarInstructions (str): instructions for the user to get the environment variables.
            url (str): The url of the MCP server github repository or webpage.
            isActive (bool): Whether the MCP server is active.
            metadata (dict): additional information about the MCP server including github_stars, etc.
    """

    def __init__(self, client, name=None, description=None, envVars=None, config=None, envVarInstructions=None, url=None, isActive=None, metadata=None):
        super().__init__(client, None)
        self.name = name
        self.description = description
        self.env_vars = envVars
        self.config = config
        self.env_var_instructions = envVarInstructions
        self.url = url
        self.is_active = isActive
        self.metadata = metadata
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'name': repr(self.name), f'description': repr(self.description), f'env_vars': repr(self.env_vars), f'config': repr(
            self.config), f'env_var_instructions': repr(self.env_var_instructions), f'url': repr(self.url), f'is_active': repr(self.is_active), f'metadata': repr(self.metadata)}
        class_name = "McpServer"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'name': self.name, 'description': self.description, 'env_vars': self.env_vars, 'config': self.config,
                'env_var_instructions': self.env_var_instructions, 'url': self.url, 'is_active': self.is_active, 'metadata': self.metadata}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class UseCaseRequirements(AbstractApiClass):
    """
        Use Case Requirements

        Args:
            client (ApiClient): An authenticated API Client instance
            datasetType (str): The project-specific enum value of the dataset type.
            name (str): The user-friendly name of the dataset type.
            description (str): The description of the dataset type.
            required (bool): True if the dataset type is required for this project.
            multi (bool): If true, multiple versions of the dataset type can be used for training.
            allowedFeatureMappings (dict): A collection of key-value pairs, with each key being a column mapping enum (see a list of column mapping enums here) and each value being in the following dictionary format: { "description": str, "allowed_feature_types": feature_type_enum, "required": bool }.
            allowedNestedFeatureMappings (dict): A collection of key-value pairs, with each key being a column mapping enum (see a list of column mapping enums here) and each value being in the following dictionary format: { "description": str, "allowed_feature_types": feature_type_enum, "required": bool }.
    """

    def __init__(self, client, datasetType=None, name=None, description=None, required=None, multi=None, allowedFeatureMappings=None, allowedNestedFeatureMappings=None):
        super().__init__(client, None)
        self.dataset_type = datasetType
        self.name = name
        self.description = description
        self.required = required
        self.multi = multi
        self.allowed_feature_mappings = allowedFeatureMappings
        self.allowed_nested_feature_mappings = allowedNestedFeatureMappings
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'dataset_type': repr(self.dataset_type), f'name': repr(self.name), f'description': repr(self.description), f'required': repr(self.required), f'multi': repr(
            self.multi), f'allowed_feature_mappings': repr(self.allowed_feature_mappings), f'allowed_nested_feature_mappings': repr(self.allowed_nested_feature_mappings)}
        class_name = "UseCaseRequirements"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'dataset_type': self.dataset_type, 'name': self.name, 'description': self.description, 'required': self.required, 'multi': self.multi,
                'allowed_feature_mappings': self.allowed_feature_mappings, 'allowed_nested_feature_mappings': self.allowed_nested_feature_mappings}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class HostedAppFileRead(AbstractApiClass):
    """
        Result of reading file content from a hosted app container.

        Args:
            client (ApiClient): An authenticated API Client instance
            content (str): The contents of the file or a portion of it.
            start (int): If present, the starting position of the read.
            end (int): If present, the last position in the file returned in this read.
            retcode (int): If the read is associated with a log the return code of the command.
    """

    def __init__(self, client, content=None, start=None, end=None, retcode=None):
        super().__init__(client, None)
        self.content = content
        self.start = start
        self.end = end
        self.retcode = retcode
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'content': repr(self.content), f'start': repr(
            self.start), f'end': repr(self.end), f'retcode': repr(self.retcode)}
        class_name = "HostedAppFileRead"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'content': self.content, 'start': self.start,
                'end': self.end, 'retcode': self.retcode}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class SpeechGenSettings(AbstractApiClass):
    """
        Unified speech generation settings combining STT, TTS, and STS.

        Args:
            client (ApiClient): An authenticated API Client instance
            speechType (dict): Dropdown for type of speech (speech_to_text, text_to_speech, speech_to_speech).
            modelsByType (dict): Maps each speech type to the list of applicable model keys.
            settingsByType (dict): Maps each speech type to its model settings dict.
    """

    def __init__(self, client, speechType=None, modelsByType=None, settingsByType=None):
        super().__init__(client, None)
        self.speech_type = speechType
        self.models_by_type = modelsByType
        self.settings_by_type = settingsByType
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'speech_type': repr(self.speech_type), f'models_by_type': repr(
            self.models_by_type), f'settings_by_type': repr(self.settings_by_type)}
        class_name = "SpeechGenSettings"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'speech_type': self.speech_type, 'models_by_type': self.models_by_type,
                'settings_by_type': self.settings_by_type}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class ChatllmProject(AbstractApiClass):
    """
        ChatLLM Project

        Args:
            client (ApiClient): An authenticated API Client instance
            chatllmProjectId (id): The ID of the chatllm project.
            name (str): The name of the chatllm project.
            description (str): The description of the chatllm project.
            customInstructions (str): The custom instructions of the chatllm project.
            createdAt (str): The creation time of the chatllm project.
            updatedAt (str): The update time of the chatllm project.
            verticalType (str): The vertical type (HEALTH or null for regular projects).
            preferences (dict): The preferences JSON for vertical projects.
            orchestratorDeploymentConversationId (id): The ID of the orchestrator deployment conversation.
    """

    def __init__(self, client, chatllmProjectId=None, name=None, description=None, customInstructions=None, createdAt=None, updatedAt=None, verticalType=None, preferences=None, orchestratorDeploymentConversationId=None):
        super().__init__(client, chatllmProjectId)
        self.chatllm_project_id = chatllmProjectId
        self.name = name
        self.description = description
        self.custom_instructions = customInstructions
        self.created_at = createdAt
        self.updated_at = updatedAt
        self.vertical_type = verticalType
        self.preferences = preferences
        self.orchestrator_deployment_conversation_id = orchestratorDeploymentConversationId
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'chatllm_project_id': repr(self.chatllm_project_id), f'name': repr(self.name), f'description': repr(self.description), f'custom_instructions': repr(self.custom_instructions), f'created_at': repr(
            self.created_at), f'updated_at': repr(self.updated_at), f'vertical_type': repr(self.vertical_type), f'preferences': repr(self.preferences), f'orchestrator_deployment_conversation_id': repr(self.orchestrator_deployment_conversation_id)}
        class_name = "ChatllmProject"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'chatllm_project_id': self.chatllm_project_id, 'name': self.name, 'description': self.description, 'custom_instructions': self.custom_instructions, 'created_at': self.created_at,
                'updated_at': self.updated_at, 'vertical_type': self.vertical_type, 'preferences': self.preferences, 'orchestrator_deployment_conversation_id': self.orchestrator_deployment_conversation_id}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class AgentSkill(AbstractApiClass):
    """
        A skill that can be attached to an agent.

        Args:
            client (ApiClient): An authenticated API Client instance
            agentSkillId (str): The unique identifier of the skill.
            skillName (str): The name of the skill.
            description (str): A description of what the skill does.
            skillDirectoryName (str): The directory name where skill files are stored.
            chatllmProjectId (str): The project ID this skill is associated with.
            systemCreated (bool): Whether this skill was created by the system.
            enabled (bool): Whether the skill is currently enabled.
            default (bool): Whether this skill is a default skill.
            display (bool): Whether this skill should be displayed prominently in the dropdown.
            createdAt (str): The timestamp when the skill was created.
            updatedAt (str): The timestamp when the skill was last updated.
    """

    def __init__(self, client, agentSkillId=None, skillName=None, description=None, skillDirectoryName=None, chatllmProjectId=None, systemCreated=None, enabled=None, default=None, display=None, createdAt=None, updatedAt=None):
        super().__init__(client, agentSkillId)
        self.agent_skill_id = agentSkillId
        self.skill_name = skillName
        self.description = description
        self.skill_directory_name = skillDirectoryName
        self.chatllm_project_id = chatllmProjectId
        self.system_created = systemCreated
        self.enabled = enabled
        self.default = default
        self.display = display
        self.created_at = createdAt
        self.updated_at = updatedAt
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'agent_skill_id': repr(self.agent_skill_id), f'skill_name': repr(self.skill_name), f'description': repr(self.description), f'skill_directory_name': repr(self.skill_directory_name), f'chatllm_project_id': repr(
            self.chatllm_project_id), f'system_created': repr(self.system_created), f'enabled': repr(self.enabled), f'default': repr(self.default), f'display': repr(self.display), f'created_at': repr(self.created_at), f'updated_at': repr(self.updated_at)}
        class_name = "AgentSkill"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'agent_skill_id': self.agent_skill_id, 'skill_name': self.skill_name, 'description': self.description, 'skill_directory_name': self.skill_directory_name, 'chatllm_project_id': self.chatllm_project_id,
                'system_created': self.system_created, 'enabled': self.enabled, 'default': self.default, 'display': self.display, 'created_at': self.created_at, 'updated_at': self.updated_at}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class CodeLlmChangedFiles(AbstractApiClass):
    """
        Code changed files

        Args:
            client (ApiClient): An authenticated API Client instance
            addedFiles (list): A list of added file paths.
            updatedFiles (list): A list of updated file paths.
            deletedFiles (list): A list of deleted file paths.
    """

    def __init__(self, client, addedFiles=None, updatedFiles=None, deletedFiles=None):
        super().__init__(client, None)
        self.added_files = addedFiles
        self.updated_files = updatedFiles
        self.deleted_files = deletedFiles
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'added_files': repr(self.added_files), f'updated_files': repr(
            self.updated_files), f'deleted_files': repr(self.deleted_files)}
        class_name = "CodeLlmChangedFiles"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'added_files': self.added_files,
                'updated_files': self.updated_files, 'deleted_files': self.deleted_files}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}



from .return_class import AbstractApiClass


class CodellmEmbeddingConstants(AbstractApiClass):
    """
        A dictionary of constants to be used in the autocomplete.

        Args:
            client (ApiClient): An authenticated API Client instance
            maxSupportedWorkspaceFiles (int): Max supported workspace files
            maxSupportedWorkspaceChunks (int): Max supported workspace chunks
            maxConcurrentRequests (int): Max concurrent requests
            fileExtensionToChunkingScheme (dict): Map between the file extensions and their chunking schema
            idleTimeoutSeconds (int): The idle timeout without any activity before the workspace is refreshed.
    """

    def __init__(self, client, maxSupportedWorkspaceFiles=None, maxSupportedWorkspaceChunks=None, maxConcurrentRequests=None, fileExtensionToChunkingScheme=None, idleTimeoutSeconds=None):
        super().__init__(client, None)
        self.max_supported_workspace_files = maxSupportedWorkspaceFiles
        self.max_supported_workspace_chunks = maxSupportedWorkspaceChunks
        self.max_concurrent_requests = maxConcurrentRequests
        self.file_extension_to_chunking_scheme = fileExtensionToChunkingScheme
        self.idle_timeout_seconds = idleTimeoutSeconds
        self.deprecated_keys = {}

    def __repr__(self):
        repr_dict = {f'max_supported_workspace_files': repr(self.max_supported_workspace_files), f'max_supported_workspace_chunks': repr(self.max_supported_workspace_chunks), f'max_concurrent_requests': repr(
            self.max_concurrent_requests), f'file_extension_to_chunking_scheme': repr(self.file_extension_to_chunking_scheme), f'idle_timeout_seconds': repr(self.idle_timeout_seconds)}
        class_name = "CodellmEmbeddingConstants"
        repr_str = ',\n  '.join([f'{key}={value}' for key, value in repr_dict.items(
        ) if getattr(self, key, None) is not None and key not in self.deprecated_keys])
        return f"{class_name}({repr_str})"

    def to_dict(self):
        """
        Get a dict representation of the parameters in this class

        Returns:
            dict: The dict value representation of the class parameters
        """
        resp = {'max_supported_workspace_files': self.max_supported_workspace_files, 'max_supported_workspace_chunks': self.max_supported_workspace_chunks,
                'max_concurrent_requests': self.max_concurrent_requests, 'file_extension_to_chunking_scheme': self.file_extension_to_chunking_scheme, 'idle_timeout_seconds': self.idle_timeout_seconds}
        return {key: value for key, value in resp.items() if value is not None and key not in self.deprecated_keys}
